@@ -24,11 +24,14 @@
 #' @param covariates The vector of names of baseline covariates
 #'   in the input data.
 #' @param freq The name of the frequency variable in the input data.
-#'   The frequencies must be the same for all observations within each 
+#'   The frequencies must be the same for all observations within each
 #'   cluster as indicated by the id. Thus freq is the cluster frequency.
 #' @param weight The name of the weight variable in the input data.
 #' @param offset The name of the offset variable in the input data.
 #' @param id The name of the id variable in the input data.
+#' @param link The link function linking the response probabilities to the
+#'   linear predictors. Options include "logit" (default), "probit", and
+#'   "cloglog" (complementary log-log).
 #' @param robust Whether a robust sandwich variance estimate should be
 #'   computed. In the presence of the id variable, the score residuals
 #'   will be aggregated for each id when computing the robust sandwich
@@ -80,6 +83,8 @@
 #'     - \code{p}: The number of parameters, including the intercept,
 #'       and regression coefficients associated with the covariates.
 #'
+#'     - \code{link}: The link function.
+#'
 #'     - \code{robust}: Whether a robust sandwich variance estimate should
 #'       be computed.
 #'
@@ -128,14 +133,16 @@
 #'
 #'     - \code{linear_predictors}: The linear fit on the logit scale.
 #'
-#'     - \code{fitted_values}: The fitted probabilities of having an event, 
-#'       obtained by transforming the linear predictors by the inverse of 
+#'     - \code{fitted_values}: The fitted probabilities of having an event,
+#'       obtained by transforming the linear predictors by the inverse of
 #'       the logit link.
 #'
 #'     - \code{rep}: The replication.
 #'
 #' * \code{p}: The number of parameters.
 #'
+#' * \code{link}: The link function.
+#'
 #' * \code{param}: The parameter names.
 #'
 #' * \code{beta}: The parameter estimate.
@@ -143,11 +150,11 @@
 #' * \code{vbeta}: The covariance matrix for parameter estimates.
 #'
 #' * \code{vbeta_naive}: The naive covariance matrix for parameter estimates.
-#' 
+#'
 #' * \code{linear_predictors}: The linear fit on the logit scale.
-#' 
+#'
 #' * \code{fitted_values}: The fitted probabilities of having an event.
-#' 
+#'
 #' * \code{terms}: The terms object.
 #'
 #' * \code{xlevels}: A record of the levels of the factors used in fitting.
@@ -205,8 +212,8 @@
 #' @export
 logisregr <- function(data, rep = "", event = "event", covariates = "",
                       freq = "", weight = "", offset = "", id = "",
-                      robust = FALSE, firth = FALSE, flic = FALSE,
-                      plci = FALSE, alpha = 0.05) {
+                      link = "logit", robust = FALSE, firth = FALSE,
+                      flic = FALSE, plci = FALSE, alpha = 0.05) {
   
   rownames(data) = NULL
   
@@ -250,10 +257,11 @@ logisregr <- function(data, rep = "", event = "event", covariates = "",
   
   fit <- logisregcpp(data = df, rep = rep, event = event,
                      covariates = varnames, freq = freq, weight = weight,
-                     offset = offset, id = id, robust = robust,
+                     offset = offset, id = id, link = link, robust = robust,
                      firth = firth, flic = flic, plci = plci, alpha = alpha)
   
   fit$p <- fit$sumstat$p[1]
+  fit$link <- fit$sumstat$link[1]
   
   if (fit$p > 0) {
     fit$param = param
